---
title: 휴대폰(PASS앱/SMS) 본인인증 추가 정보 취득방법
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 본인인증
seo:
  title: SMS본인인증 추가 정보 취득방법
  description: 다날 SMS 본인인증 이용시 인증자의 휴대폰번호와 통신사, 내/외국인 정보 등을 수집할 수 있는 방법 안내입니다.
  keywords:
    - 본인인증
tags:
  - 다날
  - 본인인증
pgCompanies:
  - 다날
searchTags:
  - 리턴값
  - 다날 추가정보
  - 추가정보
  - 다날인증
  - 휴대폰본인인증
  - SMS본인인증
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="" title="다날 SMS본인인증 이용시 휴대폰번호와 통신사,내/외국인 정보를 수집할 수 있는 방법을 안내드립니다" />

### **휴대폰(PASS앱/SMS) 본인인증 후 제공받는 정보**

- 휴대폰 본인인증 서비스는 기본적으로는 이름(name), 성별(gender), 생년월일(birthday) 정보만 받을 수 있으나, 추가 요청을 주실 경우 **전화번호(phone), 통신사 정보(carrier), 내/외국인정보(foreigner)** 를 추가로 받으실 수 있습니다.
- 해당 정보는 민감한 개인정보에 해당되어 계약 이후 추가적인 절차를 거쳐 다날에 별도 신청을 해주셔야 하며 다날 PG사와 계약을 모두 마친 후 CPID(상점아이디)가 발급되면아래 절차에 따라 진행해주시기 바랍니다.

<Indent level="1">

- 신규 가입시(미계약 상태) : 다날 계약부서에서 추가 정보 수집 안내를 드립니다.
- 계약 완료시(계약 상태) : 포트원을 통해 추가 정보 수집 요청

</Indent>

### **추가정보 수집을 위한 정보전달**

- 본인인증 시작하기 전 고객에게 휴대폰번호 수집에 대한 개인정보 제공동의 수취 에 대한 내용 고지 및 제공동의를 받으실 수 있도록 구현해주시기 바랍니다.
- 아래의 내용은 다날 설정에 필요한 정보확인이므로 기입 후 [포트원 고객지원팀↗](mailto:cs@portone.io "포트원 고객지원팀↗") (<cs@portone.io>)로 전달주시면 포트원에서 다날측으로 요청드리도록 하겠습니다.

<Indent level="1">

- 상호명 :
- 사업자번호 :
- 본인인증용 다날 상점아이디(CPID) :
- 서비스 url : (앱서비스의 경우 앱서비스로기재)
- 개인정보취급방침 url : (앱서비스의 경우 앱다운로드 경로 및 화면 캡쳐본 전달)
- 업종 :
- 필요사유:

※ 처리완료까지 최대 일주일이 소요될 수 있으며, 적용완료 후 포트원에서 메일로 안내드릴 예정입니다.

</Indent>

#### **참고사항 (포트원 이용 고객사의 개인정보처리방침 적용 예시)**

- [부산경상대학교 산학협력단 ↗](http://www.bsks.ac.kr/2014/privacy/sub1_1.asp)
- [(주)브레이브모바일 ↗](https://soomgo.com/terms/privacy)
- [휴대폰 본인인증 연동 메뉴얼 ↗](https://developers.portone.io/opi/ko/extra/identity-verification/v1/phone/readme?v=v1)
- [포트원 본인인증 조회 API 문서 ↗](https://developers.portone.io/api/rest-v1/certification#get%20%2Fcertifications%2F%7Bimp_uid%7D)
